==> netbeans_6.1.orig.tar.gz: netbeans-6.1/xml/src/org/netbeans/modules/xml/wizard/XMLContentAttributes.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 * 
 * Contributor(s):
 * 
 * Portions Copyrighted 2007 Sun Microsystems, Inc.
 */

package org.netbeans.modules.xml.wizard;

/**
 *
 * @author Sonali
 */
public class XMLContentAttributes {
    
    public XMLContentAttributes(String prefix) {
        this.prefix=prefix;
    }
    
    public int getPreferredOccurences(){
        return PREFERRED;
    }
    
    public void setPreferredOccurences(int i){
        PREFERRED = i;
    }
    
    public boolean generateOptionalAttributes(){
            return optionalAttributes;
    }
    
    public void setOptionalAttributes(boolean value){
        optionalAttributes = value;
    }
    
    public boolean generateOptionalElements(){
        return optionalElements;
    }

    public void setOptionalElements(boolean value){
        optionalElements = value;
    }
    
    public String getPrefix() {
        return prefix;
    }
    
    public void setPrefix(String pre) {
        prefix = pre;
    }
    
    public void setDepthPreferrence(int value) {
       DEPTH = value;
    }
    
    public int getDepthPreferrence(){
        return DEPTH;
    }
    
    private int PREFERRED = 3;
    private boolean optionalAttributes = true;
    private boolean optionalElements = true;  
    private String prefix="test_prefix";
    private int DEPTH = 2;

    

}

==> netbeans_6.5.orig.tar.gz: netbeans-6.5/xml/src/org/netbeans/modules/xml/wizard/XMLContentAttributes.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 * 
 * Contributor(s):
 * 
 * Portions Copyrighted 2007 Sun Microsystems, Inc.
 */

package org.netbeans.modules.xml.wizard;

import java.util.Map;

/**
 *
 * @author Sonali
 */
public class XMLContentAttributes {
    
    public XMLContentAttributes(String prefix) {
        this.prefix=prefix;
    }
    
    public int getPreferredOccurences(){
        return PREFERRED;
    }
    
    public void setPreferredOccurences(int i){
        PREFERRED = i;
    }
    
    public boolean generateOptionalAttributes(){
            return optionalAttributes;
    }
    
    public void setOptionalAttributes(boolean value){
        optionalAttributes = value;
    }
    
    public boolean generateOptionalElements(){
        return optionalElements;
    }

    public void setOptionalElements(boolean value){
        optionalElements = value;
    }
    
    public String getPrefix() {
        return prefix;
    }
    
    public void setPrefix(String pre) {
        prefix = pre;
    }
    
    public void setDepthPreferrence(int value) {
       DEPTH = value;
    }
    
    public int getDepthPreferrence(){
        return DEPTH;
    }
    
    public void setNamespaceToPrefixMap(Map<String, String> nsMap){
        nsToPre = nsMap;
    }
    
    public Map<String, String> getNamespaceToPrefixMap(){
        return nsToPre;
   
    }
    private int PREFERRED = 3;
    private boolean optionalAttributes = true;
    private boolean optionalElements = true;  
    private String prefix="test_prefix";
    private int DEPTH = 2;
    private Map<String, String> nsToPre;

    

}
